# coding=utf-8

import os
import datetime
import tempfile

from django.core.files.storage import Storage
from django.core.files import File

from .api import AtcfsApi


class AtcfsStorage(Storage):
    """
    ATCFS Storage
    """

    def __init__(self):
        self.api = AtcfsApi()

    def _open(self, name, mode='rb'):
        return File(open(self.path(name), mode))

    def save(self, name, content):
        if name is None:
            name = content.name
        # нам нужно только название без относительного пути
        name = os.path.basename(name)
        ident = self.api.upload_file(name, content)
        return ident

    def delete(self, ident):
        self.api.delete_file(ident)

    def url(self, ident):
        file_url = self.api.get_file_url(ident)
        return file_url

    def size(self, ident):
        file_info = self.api.get_file_info(ident)
        file_size = file_info['size']
        return file_size

    def name(self, ident):
        file_info = self.api.get_file_info(ident)
        file_name = file_info['name']
        return file_name

    def path(self, ident):
        """
        Загружаем файл, сохраняем его во временной папке, отдаем путь.
        """
        file_name, file_content = self.api.download_file(ident)
        dir_path = tempfile.mkdtemp()
        file_path = os.path.join(dir_path, file_name)
        fd = open(file_path, 'w')
        fd.write(file_content)
        fd.close()
        return file_path

    def exists(self, name):
        """
        Заглушка
        """
        return False

    def listdir(self, path):
        """
        Заглушка
        """
        return [], []

    def accessed_time(self, name):
        """
        Заглушка
        """
        return datetime.datetime(1, 1, 1)

    def created_time(self, name):
        """
        Заглушка
        """
        return datetime.datetime(1, 1, 1)

    def modified_time(self, name):
        """
        Заглушка
        """
        return datetime.datetime(1, 1, 1)
